Quickstart
===========================================

.. raw:: html

    <script src="https://gist.github.com/semiautomaticgit/0fdb7c2c5c0b3b990cf342d226b8ee43.js"></script>

Link to the guide:
https://colab.research.google.com/gist/semiautomaticgit/0fdb7c2c5c0b3b990cf342d226b8ee43/quickstart.ipynb
